==> haskell-bv-sized-1.0.6-81-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bv-sized.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bv-sized
version:              1.0.6
visibility:           public
id:                   bv-sized-1.0.6-CTNgVS0bSi0Cal0NzASxaY
key:                  bv-sized-1.0.6-CTNgVS0bSi0Cal0NzASxaY
license:              BSD-3-Clause
copyright:            Galois Inc., Ben Selfridge March 2018
maintainer:           benselfridge@galois.com
author:               Ben Selfridge
homepage:             https://github.com/GaloisInc/bv-sized
synopsis:
    a bitvector datatype that is parameterized by the vector width

description:
    This module defines a width-parameterized bitvector type and various associated operations.

category:             Bit Vectors
abi:                  ddd175a1eb1a622dbe334771a4db91d2
exposed:              True
exposed-modules:
    Data.BitVector.Sized Data.BitVector.Sized.Overflow
    Data.BitVector.Sized.Signed Data.BitVector.Sized.Unsigned

hidden-modules:
    Data.BitVector.Sized.Internal Data.BitVector.Sized.Panic

import-dirs:          /usr/lib/ghc-9.4.8/site-local/bv-sized-1.0.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bv-sized-1.0.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bv-sized-1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bv-sized
hs-libraries:         HSbv-sized-1.0.6-CTNgVS0bSi0Cal0NzASxaY
depends:
    base-4.17.2.1 bitwise-1.0.0.1-LxRXDkhKKVn8nOv9Ieqs0l
    bytestring-0.11.5.3 deepseq-1.4.8.0
    panic-0.4.0.1-3QvhbYIlGoL4pBeY3qhGHr
    parameterized-utils-2.1.10.0-JyLCrRSfQAsJTehHrqVew3
    random-1.2.1.3-Lrb8TDGfTan4fST0eiDAa7
    th-lift-0.8.6-HRVeiGNnDxNElRy2LmdExl

haddock-interfaces:   /usr/share/doc/haskell-bv-sized/html/bv-sized.haddock
haddock-html:         /usr/share/doc/haskell-bv-sized/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bv-sized-1.0.6-82-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bv-sized.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bv-sized
version:              1.0.6
visibility:           public
id:                   bv-sized-1.0.6-7ilQl4ey9cjJo82fjbOn7O
key:                  bv-sized-1.0.6-7ilQl4ey9cjJo82fjbOn7O
license:              BSD-3-Clause
copyright:            Galois Inc., Ben Selfridge March 2018
maintainer:           benselfridge@galois.com
author:               Ben Selfridge
homepage:             https://github.com/GaloisInc/bv-sized
synopsis:
    a bitvector datatype that is parameterized by the vector width

description:
    This module defines a width-parameterized bitvector type and various associated operations.

category:             Bit Vectors
abi:                  413e3751756f6fbd9eb1b138291cf812
exposed:              True
exposed-modules:
    Data.BitVector.Sized Data.BitVector.Sized.Overflow
    Data.BitVector.Sized.Signed Data.BitVector.Sized.Unsigned

hidden-modules:
    Data.BitVector.Sized.Internal Data.BitVector.Sized.Panic

import-dirs:          /usr/lib/ghc-9.4.8/site-local/bv-sized-1.0.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bv-sized-1.0.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bv-sized-1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bv-sized
hs-libraries:         HSbv-sized-1.0.6-7ilQl4ey9cjJo82fjbOn7O
depends:
    base-4.17.2.1 bitwise-1.0.0.1-8IL2UWmXxngEbyLtyRmQ7I
    bytestring-0.11.5.3 deepseq-1.4.8.0
    panic-0.4.0.1-3QvhbYIlGoL4pBeY3qhGHr
    parameterized-utils-2.1.10.0-3kFKGdC718e5rG7BEazzfm
    random-1.2.1.3-KqHaq6YE0664JHSWbd4LQ1
    th-lift-0.8.6-HRVeiGNnDxNElRy2LmdExl

haddock-interfaces:   /usr/share/doc/haskell-bv-sized/html/bv-sized.haddock
haddock-html:         /usr/share/doc/haskell-bv-sized/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
